@@ -1,4 +1,4 @@
 __all__ = ['MagicFile', 'MagicFileException', 'UnreadableFileException', 'NotBinaryFileException', 'NotSeekableFileException']
 
 from .file import MagicFile
-from .exceptions import MagicFileException, UnreadableFileException, NotBinaryFileException, NotSeekableFileException
+from .exceptions import MagicFileException, NotBinaryFileException
